<?php

use Illuminate\Support\Facades\Route;
use Modules\Db\Http\Controllers\CustomerOrderController;
use Modules\Db\Http\Controllers\CustomerOrderListController;
use Modules\Db\Http\Controllers\CustomerOrderStatusListController;
use Modules\Db\Http\Controllers\CustomerOrderThreadController;
use Modules\Db\Http\Controllers\DashboardController;
use Modules\Db\Http\Controllers\PendingFundsController;
use Modules\Db\Http\Controllers\ProductionPlanCalanderController;
use Modules\Db\Http\Controllers\ProductionScheduleCalanderController;
use Modules\Db\Http\Controllers\ProductionScheduleCalendarCustomerController;
use Modules\Db\Http\Controllers\SvrController;
use Modules\Db\Http\Controllers\VesselScheduleApprovalController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::prefix('db')->group(function () {
    //Route::get('/', 'DbController@index');

    Route::get('/dashboard', function () {
        return view('db::dashboard');
    })->middleware('is.logged');



    Route::get('/orderList', function () {
        return view('db::orderList');
    })->middleware('is.logged');


    Route::get('/customerOrder', function () {
        return view('db::customerOrder');
    })->middleware('is.logged');

    Route::get('/orderStatusList', function () {
        return view('db::orderStatusList');
    })->middleware('is.logged');

    Route::get('/vesselScheduleApprovalList', function () {
        return view('db::vesselScheduleApprovalList');
    })->middleware('is.logged');

    Route::get('/vesselSchedule', function () {
        return view('db::vesselSchedule');
    })->middleware('is.logged');

    Route::get('/pending_funds', function () {
        return view('db::pending_funds');
    })->middleware('is.logged');

    Route::get('/production_plan_calander', function () {
        return view('db::production_plan_calander');
    })->middleware('is.logged');

    Route::get('/production_schedule_calander', function () {
        return view('db::production_schedule_calander');
    })->middleware('is.logged');

    Route::get('/changePassword', function () {
        return view('db::changePassword');
    })->middleware('is.logged');

    Route::get('/production_schedule_calendar_by_customer', function () {
        return view('db::production_schedule_calendar_by_customer');
    })->middleware('is.logged');




    /** svrController */
    Route::get('/svr/date', [SvrController::class, 'serverDate']);
    /** End svrController */

    /** Customer Order List Controller */
    Route::get('/customerOrderList/allCustomerOrder/{year}/{month}', [CustomerOrderListController::class, 'allCustomerOrder']);
    /** End Of Customer Order List Controller */




    /** Customer Order */
    Route::get('/customerOrder/allCustomer', [CustomerOrderController::class, 'allCustomers']);
    Route::get('/customerOrder/getCustomer/{id}', [CustomerOrderController::class, 'SelectedCustomersData']);
    Route::get('/customerOrder/allCountries', [CustomerOrderController::class, 'allCountries']);
    Route::get('/customerOrder/allShippingTerms', [CustomerOrderController::class, 'allShippingTerms']);
    Route::get('/customerOrder/allDrainHoleSize', [CustomerOrderController::class, 'allDrainHoleSize']);
    Route::get('/customerOrder/allDrainHoleShape', [CustomerOrderController::class, 'allDrainHoleShape']);
    Route::get('/customerOrder/allProductMix', [CustomerOrderController::class, 'allProductMix']);
    Route::get('/customerOrder/allWashedLevel', [CustomerOrderController::class, 'allWashedLevel']);
    Route::get('/customerOrder/allOrderDataWithToken/{id}/{token}/{action}', [CustomerOrderController::class, 'allOrderDataWithToken']);
    Route::get('/customerOrder/allOrderData/{id}', [CustomerOrderController::class, 'allOrderData']);
    Route::get('/customerOrder/getCustomerAllOrderData/{id}', [CustomerOrderController::class, 'getCustomerAllOrderData']);
    Route::get('/customerOrder/getCustomerOrderData/{id}', [CustomerOrderController::class, 'getCustomerOrderData']);
    Route::get('/customerOrder/getCustomerMainOrder/{id}', [CustomerOrderController::class, 'getCustomerMainOrder']);
    Route::get('/customerOrder/allAttachment/{id}', [CustomerOrderController::class, 'allAttachment']);
    Route::get('/customerOrder/allAttachmentEditViewMode/{id}', [CustomerOrderController::class, 'allAttachmentEditViewMode']);
    Route::post('/customerOrder/saveOrderData', [CustomerOrderController::class, 'saveOrderData']);
    Route::post('/customerOrder/updateOrderData/{id}', [CustomerOrderController::class, 'updateOrderData']);
    Route::post('/customerOrder/saveCustomerOrder', [CustomerOrderController::class, 'saveCustomerOrder']);
    Route::post('/customerOrder/updateCustomerOrder/{id}', [CustomerOrderController::class, 'updateCustomerOrder']);

    Route::delete('/customerOrder/deleteOrderData/{id}', [CustomerOrderController::class, 'deleteOrderData']);
    Route::delete('/customerOrder/deleteAttachment/{id}', [CustomerOrderController::class, 'deleteAttachment']);
    Route::post('/customerOrder/uploadAttachment', [CustomerOrderController::class, 'uploadAttachment']);
    Route::get('/customerOrder/checkOrderStatus/{id}', [CustomerOrderController::class, 'checkOrderStatus']);
    Route::get('/customerOrder/customerAllDeliveryAddress/{id}', [CustomerOrderController::class, 'customerAllDeliveryAddress']);
    Route::get('/customerOrder/isDuplicateFactoryPO/{id}', [CustomerOrderController::class, 'isDuplicateFactoryPO']);
    Route::post('/customerOrder/saveAttachmentViewOrder', [CustomerOrderController::class, 'saveAttachmentViewOrder']);
    /** End Customer Order */


    /** Customer Order Thread */
    Route::post('/customerOrderThread/submit', [CustomerOrderThreadController::class, 'submit']);
    Route::get('/customerOrderThread/loadCustomerOrderThread/{order_id}', [CustomerOrderThreadController::class, 'loadCustomerOrderThread']);
    /** End of Customer Order Thread  */


    /** Customer Order Status List Controller */
    Route::get('/CustomerOrderStatusListController/allCustomerOrder/{year}/{month}/{order_status}/{production_status}', [CustomerOrderStatusListController::class, 'allCustomerOrder']);
    Route::post('/CustomerOrderStatusListController/shipping_status', [CustomerOrderStatusListController::class, 'shipping_status']);
    Route::get('/CustomerOrderStatusListController/getProductionStatus', [CustomerOrderStatusListController::class, 'getProductionStatus']);
    Route::get('/CustomerOrderStatusListController/getOrderStatus', [CustomerOrderStatusListController::class, 'getOrderStatus']);
    Route::get('/CustomerOrderStatusListController/getShippingStatus', [CustomerOrderStatusListController::class, 'getShippingStatus']);
    /** End Of Customer Order Status List Controller */


    /** svrController */
    Route::get('/svr/date', [SvrController::class, 'serverDate']);
    /** End svrController */

    /** DashBoardController */
    Route::get('/dashboard/count/{year}/{month}', [DashboardController::class, 'count']);
    Route::get('/dashboard/tableProducedQuantity/{date}', [DashboardController::class, 'tableProducedQuantity']);
    /** End of DashBoardController */




    /** Vessel Schedule */
    Route::get('/VesselScheduledController/getFactoryOrderNo', [VesselScheduleApprovalController::class, 'getFactoryOrderNo']);
    Route::get('/VesselScheduledController/getCustomerOrderData/{id}', [VesselScheduleApprovalController::class, 'getCustomerOrderData']);
    Route::post('/VesselScheduled/saveSchedule', [VesselScheduleApprovalController::class, 'saveSchedule']);
    Route::get('/vesselSchedule/allSchedule', [VesselScheduleApprovalController::class, 'getScheduleData']);
    Route::get('/VesselSchedule/getCurrencyPrimaryID', [VesselScheduleApprovalController::class, 'getCurrencyPrimaryID']);
    Route::get('/VesselScheduleController/getVsData/{id}', [VesselScheduleApprovalController::class, 'getVsData']);
    Route::delete('/vesselScheduleController/deleteScheduleAttachment/{id}', [VesselScheduleApprovalController::class, 'deleteScheduleAttachment']);
    Route::post('/VesseSchedulelController/update/{id}', [VesselScheduleApprovalController::class, 'updateSchedule']);
    Route::delete('/VesselScheduleController/delete/{id}', [VesselScheduleApprovalController::class, 'deleteSchedule']);


    Route::get('/VesselScheduleController/genarateExternalID', [VesselScheduleApprovalController::class, 'genarateExternalID']);
    Route::put('/VesselScheduleController/approve/{id}', [VesselScheduleApprovalController::class, 'approve']);
    Route::put('/VesselScheduleController/revise/{id}', [VesselScheduleApprovalController::class, 'revise']);
    Route::put('/VesselScheduleController/reject/{id}', [VesselScheduleApprovalController::class, 'reject']);

    Route::get('/customerOrderList/allScheduleAttachment/{id}', [VesselScheduleApprovalController::class, 'allScheduleAttachment']);
    /** End of Vessel Schedule  */



    /** Pending Funds Controller */
    Route::get('/PendingFundsController/allCustomerOrder', [PendingFundsController::class, 'allCustomerOrder']);
    /** End Of Pending Funds Controller */



    /** Production Plan Calander Controller */
    Route::get('/ProductionPlanCalanderController/loadProductionPlanToCalander', [ProductionPlanCalanderController::class, 'loadProductionPlanToCalander']);
    /** End Of Production Plan Calander Controller */

   /**Production Schedule Calendar Controller */
   Route::get('/ProductionScheduleCalanderController/loadProductionScheduleToCalander', [ProductionScheduleCalanderController::class, 'loadProductionScheduleToCalander']);
   /**End of Production Schedule Calendar Controller */ 



   /**Production Schedule Calendar Controller */
   Route::get('/ProductionScheduleCalendarCustomerController/loadProductionScheduleToCalander', [ProductionScheduleCalendarCustomerController::class, 'loadProductionScheduleToCalander']);
   /**End of Production Schedule Calendar Controller */ 
});
